mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
* [patch 6/9] s390: z90crypt reader task rescheduling.
@ 2005-03-02 16:46 Martin Schwidefsky
  0 siblings, 0 replies; only message in thread
From: Martin Schwidefsky @ 2005-03-02 16:46 UTC (permalink / raw)
  To: akpm, linux-kernel

[patch 6/9] s390: z90crypt reader task rescheduling.

From: Eric Rossman <edrossma@us.ibm.com>

z90crypt device driver changes:
 - Correct the condition for which the reader task is scheduled to run.

Signed-off-by: Martin Schwidefsky <schwidefsky@de.ibm.com>

diffstat:
 drivers/s390/crypto/z90main.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff -urN linux-2.6/drivers/s390/crypto/z90main.c linux-2.6-patched/drivers/s390/crypto/z90main.c
--- linux-2.6/drivers/s390/crypto/z90main.c	2005-03-02 08:37:30.000000000 +0100
+++ linux-2.6-patched/drivers/s390/crypto/z90main.c	2005-03-02 17:00:13.000000000 +0100
@@ -2657,8 +2657,8 @@
 
 	/**
 	 * we use workavail = 2 to ensure 2 passes with nothing dequeued before
 	 * exiting the loop. If pendingq_count == 0 after the loop, there is no
 	 * work remaining on the queues.
 	 */
 	resp_addr = 0;
 	workavail = 2;
@@ -2697,7 +2697,7 @@
 		spin_unlock_irq(&queuespinlock);
 	}
 
-	if (pendingq_count)
+	if (pendingq_count + requestq_count)
 		z90crypt_schedule_reader_timer();
 }
 

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2005-03-02 16:49 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -2657,8 +2657,8 @@
 	/**
 	 * we use workavail = 2 to ensure 2 passes with nothing dequeued before
-	 * exiting the loop. If pendingq_count == 0 after the loop, there is no
-	 * work remaining on the queues.
+	 * exiting the loop. If (pendingq_count+requestq_count) == 0 after the
+	 * loop, there is no work remaining on the queues.
 	 */
 	resp_addr = 0;
2005-03-02 16:46 [patch 6/9] s390: z90crypt reader task rescheduling Martin Schwidefsky

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®